@@ -279,35 +279,33 @@ sub _isa_color {
 }
 
 sub calculate_color {
-  my ($self,$score) = @_;
+  my ($self,$score,$min,$max,$range) = @_;
   $score ||= 0;
 
   # relative score
-  my $min   = $self->min_score;
-  my $max   = $self->max_score;
-  my $range = $self->score_range;
-
+  $min   = $self->min_score   || 0 unless defined $min;
+  $max   = $self->max_score unless defined $max;
+  $range = $self->score_range || 1 unless defined $range;
   # reset off-scale scores
-  $score = $min if $score < $min;
-  $score = $max if $score > $max;
+  $score = $min if $score < $min && $min;
+  $score = $max if $score > $max && $max;
   my $score_diff = ($score - $min)/$range;
 
   # Hue 
   my $hue    = $self->h_start;
   my $h_diff = $score_diff * $self->h_range;
   $hue += $h_diff;
-  $hue = int($hue+0.5);
+  $hue = $hue < 255 ? int($hue+0.5) : 255; 
 
   # Saturation
   my $sat = $self->s_start;
   $sat += $score_diff * $self->s_range; 
-  $sat = int($sat+0.5);
+  $sat = $sat < 255 ? int($sat+0.5) : 255;
 
   # Brightness
   my $bri = $self->v_start;
   $bri += $score_diff * $self->v_range;
-  $bri = int($bri + 0.5);
-
+  $bri = $bri < 255 ? int($bri + 0.5) : 255;
   return $self->HSVtoRGB($hue,$sat,$bri);
 }
 
